@@ -1,9 +1,9 @@
 # SystemC - SystemC Perl Interface
-# $Revision: #58 $$Date: 2004/11/18 $$Author: ws150726 $
+# $Revision: 1.60 $$Date: 2005-03-01 17:59:56 -0500 (Tue, 01 Mar 2005) $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2001-2004 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2005 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -18,7 +18,7 @@ package SystemC::Netlist::AutoTrace;
 use File::Basename;
 
 use SystemC::Netlist::Module;
-$VERSION = '1.163';
+$VERSION = '1.170';
 use strict;
 
 use vars qw ($Setup_Ident_Code);	# Local use for recursion only
@@ -185,7 +185,7 @@ sub _tracer_setup {
 	if ($netref->array) {
 	    $accessor .= "[i]";
 	}
-	if (($netref->width||0) > 32 && !$scbv) {
+	if (($netref->width||0) > 64 && !$scbv) {
 	    $accessor .= "[0]";
 	}
 	if (!$netref->simple_type) {
@@ -365,8 +365,10 @@ sub _write_tracer_init_recurse {
 	$fileref->printf("${indent}\{ // %s\n", $tracesref->{modhier});
     } else {
 	$fileref->printf("${indent}\{\n");
-	$fileref->printf("${indent} vcdp->module(prefix+\"%s\");  // Is-a %s\n"
-			 , _dedot($tracesref->{modhier}), $modref->name);
+	if ($#{$tracesref->{vars}} >= 0) {
+	    $fileref->printf("${indent} vcdp->module(prefix+\"%s\");  // Is-a %s\n"
+			     , _dedot($tracesref->{modhier}), $modref->name);
+	}
     }
 
     foreach my $tref (@{$tracesref->{vars}}) {
@@ -421,6 +423,9 @@ sub _write_tracer_init_recurse {
 	    } elsif ($width <= 32) {
 		$fileref->printf("vcdp->declBus  (${c},\"%s\",%s,%d,%d"
 				 ,$name, $arraynum,$netref->msb, $netref->lsb);
+	    } elsif ($width <= 64) {
+		$fileref->printf("vcdp->declQuad  (${c},\"%s\",%s,%d,%d"
+				 ,$name, $arraynum,$netref->msb, $netref->lsb);
 	    } else {
 		$fileref->printf("vcdp->declArray(${c},\"%s\",%s,%d,%d",
 				 ,$name, $arraynum,$netref->msb, $netref->lsb);
@@ -473,8 +478,10 @@ sub _write_tracer_change_recurse {
     my $mod = $self->name;
     my $modref = $tracesref->{modref};
     $fileref->printf("${indent}\{\n");
-    $fileref->printf("${indent} register %s* ts = %s;\n"
-		     , $modref->name, $tracesref->{nethier});
+    if ($#{$tracesref->{vars}} >= 0) {
+	$fileref->printf("${indent} register %s* ts = %s;\n"
+			 , $modref->name, $tracesref->{nethier});
+    }
 
     my $use_activity=$self->_autotrace('activity');
     if ($use_activity) {
@@ -521,6 +528,9 @@ sub _write_tracer_change_recurse {
 	} elsif ($netref->width <= 32) {
 	    $fileref->printf("vcdp->${mode}Bus  (c,  %s,%d"
 			     ,${accessor}, $netref->width);
+	} elsif ($netref->width <= 64) {
+	    $fileref->printf("vcdp->${mode}Quad  (c,  %s,%d"
+			     ,${accessor}, $netref->width);
 	} else {
 	    $fileref->printf("vcdp->${mode}Array(c,&(%s),%d",
 			     ,${accessor}, $netref->width);
@@ -567,7 +577,7 @@ It is called from SystemC::Netlist::Module.
 
 The latest version is available from CPAN and from L<http://www.veripool.com/>.
 
-Copyright 2001-2004 by Wilson Snyder.  This package is free software; you
+Copyright 2001-2005 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
