@@ -1,9 +1,9 @@
-// $Revision: #4 $$Date: 2004/08/12 $$Author: ws150726 $ -*- SystemC -*-
+// $Revision: 1.5 $$Date: 2005-03-01 17:59:56 -0500 (Tue, 01 Mar 2005) $$Author: wsnyder $ -*- SystemC -*-
 //=============================================================================
 //
 // THIS MODULE IS PUBLICLY LICENSED
 //
-// Copyright 2001-2004 by Wilson Snyder.  This program is free software;
+// Copyright 2001-2005 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // General Public License or the Perl Artistic License.
 //
@@ -13,11 +13,12 @@
 // for more details.
 //
 //=============================================================================
-//
-// AUTHOR:  Wilson Snyder
-//
-// DESCRIPTION: Tracing in SpTraceVcd Format
-//
+///
+/// \file
+/// \brief C++ Tracing in VCD Format
+///
+/// AUTHOR:  Wilson Snyder
+///
 //=============================================================================
 
 #ifndef _SPTRACEVCDC_H_
@@ -35,41 +36,45 @@ using namespace std;
 
 //=============================================================================
 // SpTraceVcdSig
+/// Internal data on one signal being traced.
 
 class SpTraceVcdSig {
 protected:
     friend class SpTraceVcd;
-    uint32_t		m_code;		// Code number
-    int			m_bits;		// Size of value
+    uint32_t		m_code;		///< VCD file code number
+    int			m_bits;		///< Size of value in bits
     SpTraceVcdSig (uint32_t code, int bits)
 	: m_code(code), m_bits(bits) {}
 };
 
 //=============================================================================
-// SpTraceVcdSig
 
 typedef void (*SpTraceCallback_t)(SpTraceVcd* vcdp, void* userthis, uint32_t code);
 class SpTraceCallInfo;
 
+//=============================================================================
+// SpTraceVcd
+/// Create a SystemPerl VCD dump
+
 class SpTraceVcd {
 private:
-    bool 		m_isOpen;	// True indicates open file
-    int			m_fd;		// File descriptor we're writing to
-    string		m_filename;	// Filename we're writing to (if open)
-    size_t		m_rolloverMB;	// MB of file size to rollover at
-    int			m_modDepth;	// Depth of module hiearchy
-    bool		m_fullDump;	// True indicates dump ignoring if changed
-    uint32_t		m_nextCode;	// Next code number to assign
-    string		m_modName;	// Module name being traced now
-    char*		m_wrBufp;	// Output buffer
-    char*		m_writep;	// Write pointer into output buffer
+    bool 		m_isOpen;	///< True indicates open file
+    int			m_fd;		///< File descriptor we're writing to
+    string		m_filename;	///< Filename we're writing to (if open)
+    size_t		m_rolloverMB;	///< MB of file size to rollover at
+    int			m_modDepth;	///< Depth of module hiearchy
+    bool		m_fullDump;	///< True indicates dump ignoring if changed
+    uint32_t		m_nextCode;	///< Next code number to assign
+    string		m_modName;	///< Module name being traced now
+    char*		m_wrBufp;	///< Output buffer
+    char*		m_writep;	///< Write pointer into output buffer
 
-    vector<SpTraceVcdSig>	m_sigs;		// Pointer to signal information
-    vector<uint32_t>		m_sigs_oldval;	// Pointer to old signal values
-    vector<SpTraceCallInfo*>	m_callbacks;	// Routines to perform dumping
+    vector<SpTraceVcdSig>	m_sigs;		///< Pointer to signal information
+    vector<uint32_t>		m_sigs_oldval;	///< Pointer to old signal values
+    vector<SpTraceCallInfo*>	m_callbacks;	///< Routines to perform dumping
     typedef map<string,string>	NameMap;
-    NameMap*			m_namemapp;	// List of names for the header
-    static vector<SpTraceVcd*>	s_vcdVecp;	// List of all created traces
+    NameMap*			m_namemapp;	///< List of names for the header
+    static vector<SpTraceVcd*>	s_vcdVecp;	///< List of all created traces
 
     size_t	bufferSize() { return 256*1024; }  // See below for slack calculation
     void bufferFlush();
@@ -114,21 +119,25 @@ public:
     ~SpTraceVcd();
 
     // ACCESSORS
+    /// Inside dumping routines, return next VCD signal code
     uint32_t nextCode() const {return m_nextCode;}
+    /// Set size in megabytes after which new file should be created
     void rolloverMB(size_t rolloverMB) { m_rolloverMB=rolloverMB; };
 
     // METHODS
-    void open (const char* filename);	// Open the file
-    void openNext (bool incFilename);	// Open next data-only file
-    void flush() { bufferFlush(); }	// Flush any remaining data
-    static void flush_all();		// Flush any remaining data from all files
-    void close ();			// Close the file
+    void open (const char* filename);	///< Open the file
+    void openNext (bool incFilename);	///< Open next data-only file
+    void flush() { bufferFlush(); }	///< Flush any remaining data
+    static void flush_all();		///< Flush any remaining data from all files
+    void close ();			///< Close the file
 
+    /// Inside dumping routines, declare callbacks for tracings
     void addCallback (SpTraceCallback_t init, SpTraceCallback_t full, SpTraceCallback_t change,
 		      void* userthis);
 
-    void init ();
+    /// Inside dumping routines, declare a module
     void module (const string name);
+    /// Inside dumping routines, declare a signal
     void declBit   (uint32_t code, const char* name, int arraynum);
     void declBus   (uint32_t code, const char* name, int arraynum, int msb, int lsb);
     void declQuad  (uint32_t code, const char* name, int arraynum, int msb, int lsb);
@@ -138,7 +147,7 @@ public:
     // Regular dumping
     void dump     (double timestamp);
 
-    // Full dumping
+    /// Inside dumping routines, dump one signal
     inline void fullBit (uint32_t code, const uint32_t newval) {
 	// Note the &1, so we don't require clean input -- makes more common no change case faster
 	m_sigs_oldval[code] = newval;
@@ -175,7 +184,7 @@ public:
 	bufferCheck();
     }
 
-    // Incremental dumpings
+    /// Inside dumping routines, dump one signal if it has changed
     inline void chgBit (uint32_t code, const uint32_t newval) {
 	if (m_sigs_oldval[code] != newval) { fullBit (code, newval); }
     }
@@ -197,19 +206,26 @@ public:
 
 //=============================================================================
 // SpTraceVcdCFile
-// This class is used by C standalone simulations
+/// Create a VCD dump file in C standalone (no SystemC) simulations.
 
 class SpTraceVcdCFile {
-    SpTraceVcd		m_sptrace;
+    SpTraceVcd		m_sptrace;	///< SystemPerl trace file being created
 public:
     SpTraceVcdCFile() {}
     ~SpTraceVcdCFile() {}
+    /// Open a new VCD file
     void open (const char* filename) { m_sptrace.open(filename); }
+    /// Continue a VCD dump by rotating to a new file name
     void openNext (bool incFilename=true) { m_sptrace.openNext(incFilename); }
+    /// Set size in megabytes after which new file should be created
     void rolloverMB(size_t rolloverMB) { m_sptrace.rolloverMB(rolloverMB); };
+    /// Close dump
     void close() { m_sptrace.close(); }
+    /// Flush dump
     void flush() { m_sptrace.flush(); }
+    /// Write one cycle of dump data
     void dump (double timestamp) { m_sptrace.dump(timestamp); }
+    /// Internal class access
     inline SpTraceVcd* spTrace () { return &m_sptrace; };
 };
 
